## cdist-type__link(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__link - Manage links (hard and symbolic)

## 2. DESCRIPTION

This cdist type allows you to manage hard and symbolic links. The given object id is the destination for the link.

## 3. REQUIRED PARAMETERS

source
  Specifies the link source.
type
  Specifies the link type: Either hard or symoblic.

## 4. OPTIONAL PARAMETERS

state
  present or absent, defaults to present

## 5. EXAMPLES

    # Create hard link of /etc/shadow
    __link /root/shadow --source /etc/shadow --type hard

    # Relative symbolic link
    __link /etc/apache2/sites-enabled/www.test.ch   \
       --source ../sites-available/www.test.ch      \
       --type symbolic

    # Absolute symbolic link
    __link /opt/plone --source /home/services/plone --type symbolic

    # Remove link
    __link /opt/plone --state absent

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011-2012 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).